yt.visualization.volume_rendering.camera.MosaicFisheyeCamera.draw_domain — The yt Project 3.2-dev documentation

# yt.visualization.volume_rendering.camera.MosaicFisheyeCamera.draw_domain

`MosaicFisheyeCamera.` `draw_domain`(im, alpha=0.3)

  Draws domain edges on an existing volume rendering.

  Draws a white wireframe on the domain edges.

  Parameters: | im: Numpy ndarray : Existing image that has the same resolution as the Camera, which will be painted by grid lines. alpha : float, optional The alpha value for the wireframe being drawn. Used to control how bright the lines are with respect to the image. Default : 0.3
  Returns: | nim: Numpy ndarray : A new image with the domain lines drawn

  Examples

      >>> im = cam.snapshot()
      >>> nim = cam.draw_domain(im)
      >>> write_bitmap(nim, 'render_with_domain_boundary.png')